Totals are calculated using all grouping variables, including treat_var and
cols from the table level. If by variables are included, the grouping of the
total and the application of denominators becomes ambiguous. You will be
warned specifically if a percent is included in the format. To rectify this,
use set_denoms_by(), and the grouping of add_total_row() will
be updated accordingly.
Note that when using add_total_row() with set_pop_data(), you
should call add_total_row() AFTER calling set_pop_data(),
otherwise there is potential for unexpected behaivior with treatment groups.