set_indentation: Set the option to prefix the row_labels in the inner count_layer
Description
When a count layer uses nesting (i.e. triggered by set_nest_count),
the indentation argument's value will be used as a prefix for the inner layer's
records
Usage
set_indentation(e, indentation)
Value
The modified count_layer environment
Arguments
- e
A count_layer object
- indentation
A character to prefix the row labels in an inner
count layer